import React from 'react';
import { Button as AntButton, Tooltip } from 'antd';
import { command, utils } from '@re-editor/core';

import Icon from '~/components/Icon';
import Context from '~/components/Context';

export default class Button extends React.Component {
  handleMouseDown = event => {
    event.preventDefault();

    const { type, onMouseDown } = this.props;
    if (onMouseDown) {
      onMouseDown();
    } else {
      const { editor } = this.context;
      command(editor)(type);
    }
  };

  isActive = () => {
    const { type } = this.props;
    const { value } = this.context;
    return utils.isActive(utils.toValue(value), type);
  };

  render() {
    const { type, title, icon } = this.props;

    return (
      <Tooltip title={title || type}>
        <AntButton
          size="small"
          onMouseDown={this.handleMouseDown}
          type={this.isActive() ? 'primary' : ''}
        >
          <Icon type={`icon-${icon || type}`} />
        </AntButton>
      </Tooltip>
    );
  }
}
Button.Group = AntButton.Group;
Button.contextType = Context;
